@@ -22,7 +22,7 @@ add the necessary bootstrapping code to your application.
 __all__ = ["HASHFILE_NAME","IntegrityCheckError",
            "IntegrityCheckFailed","IntegrityCheckMissing",
            "SignedImportManager","SignedLoader","RSAKey",
-           "DefaultImporter"]
+           "DefaultImporter","DummySignedImportManager"]
 
 
 #  Careful now, we can't just import things willy-nilly.  Make sure you
@@ -220,10 +220,10 @@ class _signedimp_util:
                 raise ValueError("invalid base64-encoded data")
         bytes = []
         while n > 0:
-            bytes.append(chr(n & 0x000000FF))
-            bytes.append(chr((n & 0x0000FF00) >> 8))
-            bytes.append(chr((n & 0x00FF0000) >> 16))
-            bytes.append(chr((n & 0xFF000000) >> 24))
+            bytes.append(chr((n >> 0)  & 0x000000FF))
+            bytes.append(chr((n >> 8)  & 0x0000FF))
+            bytes.append(chr((n >> 16) & 0x00FF))
+            bytes.append(chr((n >> 24) & 0xFF))
             n = (n & 0x00000000) >> 32
         while len(bytes) < 3:
             bytes.append("\x00")
@@ -476,6 +476,17 @@ class SignedHashDatabase(object):
             hashes.append((htyp,hval))
 
 
+class DummySignedHashDatabase(SignedHashDatabase):
+    """SignedHashDatabase that reports everything as verified.
+
+    This is mostly useful for DummySignedImportManager, which can be used
+    to disabled signed imports on a modified executable.
+    """
+    def parse_hash_data(self,hashdata):
+        pass
+    def verify(self,path,data):
+        pass
+
 
 class SignedImportManager(object):
     """Meta-path import hook for managing signed imports.
@@ -488,10 +499,12 @@ class SignedImportManager(object):
     This will place the manager as the first entry on sys.meta_path.
     """
 
+    SignedHashDatabaseClass = SignedHashDatabase
+
     def __init__(self,valid_keys=[]):
         self.valid_keys = [k for k in valid_keys]
         self.module_aliases = {}
-        self.hashdb = SignedHashDatabase(self.valid_keys)
+        self.hashdb = self.SignedHashDatabaseClass(self.valid_keys)
         self._hashdb_cache = {}
 
     def add_valid_key(self,key):
@@ -637,7 +650,7 @@ class SignedImportManager(object):
         """
         if path is None:
             hashdata = loader.get_data(HASHFILE_NAME)
-            hashdb = SignedHashDatabase(self.valid_keys)
+            hashdb = self.SignedHashDatabaseClass(self.valid_keys)
             hashdb.parse_hash_data(hashdata)
         else:
             try:
@@ -645,7 +658,7 @@ class SignedImportManager(object):
             except KeyError:
                 hashdata = loader.get_data(path)
                 root_path = os.path.dirname(path)
-                hashdb = SignedHashDatabase(self.valid_keys,root_path=root_path)
+                hashdb = self.SignedHashDatabaseClass(self.valid_keys,root_path=root_path)
                 hashdb.parse_hash_data(hashdata)
                 self._hashdb_cache[path] = hashdb
         return hashdb
@@ -669,7 +682,7 @@ class SignedImportManager(object):
                 finally:
                     f.close()
                 root_path = os.path.dirname(hashfile)
-                hashdb = SignedHashDatabase(self.valid_keys,root_path=root_path)
+                hashdb = self.SignedHashDatabaseClass(self.valid_keys,root_path=root_path)
                 hashdb.parse_hash_data(hashdata)
                 self._hashdb_cache[hashfile] = hashdb
                 return path,hashdb
@@ -734,6 +747,16 @@ class SignedImportManager(object):
             return self._orig_load_source(name,pathname)
 
 
+class DummySignedImportManager(SignedImportManager):
+    """SignedImportManager that reports everything as verified.
+
+    This is mostly useful for disablying signed imports on an already-signed
+    executable - you just sign it again using this class to disable all
+    signature checking.
+    """
+    SignedHashDatabaseClass = DummySignedHashDatabase
+
+
 class SignedLoader:
     """Wrapper class for managing signed imports from a specific loader.
 
@@ -962,7 +985,7 @@ class SignedLoader:
             exec code in mod.__dict__
         except Exception:
             if created:
-                sys.modules.pop(fullname)
+                sys.modules.pop(fullname,None)
             raise
         return mod
 
