@@ -55,6 +55,13 @@ def _get_bootstrap_code_rpython(key):
     b64unquad_source = _getsrc(bootstrap._signedimp_util._b64unquad,"    ")
 
     pubkey = key.get_public_key()
+
+    import os
+    import sys
+    if sys.platform == "win32":
+        O_BINARY = os.O_BINARY
+    else:
+        O_BINARY = 0
      
     return """
 
@@ -134,9 +141,9 @@ def _make_signedimp_verify(orig_verify):
         zero = rbigint(sign=1)
         while n.gt(zero):
             rbytes +=chr(n.and_(rbigint.fromint(0x000000FF)).toint())
-            rbytes +=chr(n.and_(rbigint.fromint(0x0000FF00)).rshift(8).toint())
-            rbytes +=chr(n.and_(rbigint.fromint(0x00FF0000)).rshift(16).toint())
-            rbytes +=chr(n.and_(rbigint.fromint(0xFF000000)).rshift(24).toint())
+            rbytes +=chr(n.rshift(8).and_(rbigint.fromint(0x0000FF)).toint())
+            rbytes +=chr(n.rshift(16).and_(rbigint.fromint(0x00FF)).toint())
+            rbytes +=chr(n.rshift(24).and_(rbigint.fromint(0xFF)).toint())
             n = n.rshift(32)
         i = len(rbytes) - 1
         while i > 0 and rbytes[i] == "\\x00":
@@ -154,9 +161,8 @@ def _make_signedimp_verify(orig_verify):
     RSAKey._math.long_to_bytes = staticmethod(_bigint_long_to_bytes)
     RSAKey._math.bytes_to_long = staticmethod(_bigint_bytes_to_long)
 
-    import os
     def readfile(pathnm):
-        fh = os_open(pathnm,os.O_BINARY,0)
+        fh = os_open(pathnm,%(O_BINARY)d,0)
         try:
             data = ""
             new_data = os_read(fh,1024*64)
